# ---------------------------------------------------------------------------- #
#                                  Vocabulary                                  #
# ---------------------------------------------------------------------------- #

from typing import Dict, List


bullshit_words: Dict[str, List[str]] = {
    "nCosmos": [
        "cosmos",
        "quantum soup",
        "infinite",
        "universe",
        "galaxy",
        "multiverse",
        "grid",
        "quantum matrix",
        "totality",
        "quantum cycle",
        "nexus",
        "planet",
        "solar system",
        "world",
        "stratosphere",
        "dreamscape",
        "biosphere",
        "dreamtime",
    ],
    "nPerson": [
        "being",
        "child",
        "traveller",
        "entity",
        "lifeform",
        "wanderer",
        "visitor",
        "prophet",
        "seeker",
        "Indigo Child",
    ],
    "nPersonPlural": [
        "beings",
        "travellers",
        "entities",
        "lifeforms",
        "dreamweavers",
        "adventurers",
        "pilgrims",
        "warriors",
        "messengers",
        "dreamers",
        "storytellers",
        "seekers",
        "spiritual brothers and sisters",
        "mystics",
        "starseeds",
    ],
    "nMass": [
        "consciousness",
        "nature",
        "beauty",
        "knowledge",
        "truth",
        "life",
        "healing",
        "potential",
        "freedom",
        "purpose",
        "coherence",
        "choice",
        "passion",
        "understanding",
        "balance",
        "growth",
        "inspiration",
        "conscious living",
        "energy",
        "health",
        "spacetime",
        "learning",
        "being",
        "wisdom",
        "stardust",
        "sharing",
        "science",
        "curiosity",
        "hope",
        "wonder",
        "faith",
        "fulfillment",
        "peace",
        "rebirth",
        "self-actualization",
        "presence",
        "power",
        "will",
        "flow",
        "potentiality",
        "chi",
        "intuition",
        "synchronicity",
        "wellbeing",
        "joy",
        "love",
        "karma",
        "life-force",
        "awareness",
        "guidance",
        "transformation",
        "grace",
        "divinity",
        "non-locality",
        "inseparability",
        "interconnectedness",
        "transcendence",
        "empathy",
        "insight",
        "rejuvenation",
        "ecstasy",
        "aspiration",
        "complexity",
        "serenity",
        "intention",
        "gratitude",
        "starfire",
        "manna",
    ],
    "nMassBad": [
        "turbulence",
        "pain",
        "suffering",
        "stagnation",
        "desire",
        "bondage",
        "greed",
        "selfishness",
        "ego",
        "dogma",
        "illusion",
        "delusion",
        "yearning",
        "discontinuity",
        "materialism",
    ],
    "nOurPlural": [
        "souls",
        "lives",
        "dreams",
        "hopes",
        "bodies",
        "hearts",
        "brains",
        "third eyes",
        "essences",
        "chakras",
        "auras",
    ],
    "nPath": [
        "circuit",
        "mission",
        "journey",
        "path",
        "quest",
        "vision quest",
        "story",
        "myth",
    ],
    "nOf": [
        "quantum leap",
        "evolution",
        "spark",
        "lightning bolt",
        "reintegration",
        "vector",
        "rebirth",
        "revolution",
        "wellspring",
        "fount",
        "source",
        "fusion",
        "canopy",
        "flow",
        "network",
        "current",
        "transmission",
        "oasis",
        "quantum shift",
        "paradigm shift",
        "metamorphosis",
        "harmonizing",
        "reimagining",
        "rekindling",
        "unifying",
        "osmosis",
        "vision",
        "uprising",
        "explosion",
    ],
    "ing": [
        "flowering",
        "unfolding",
        "blossoming",
        "awakening",
        "deepening",
        "refining",
        "maturing",
        "evolving",
        "summoning",
        "unveiling",
        "redefining",
        "condensing",
        "ennobling",
        "invocation",
    ],
    "adj": [
        "enlightened",
        "zero-point",
        "quantum",
        "high-frequency",
        "Vedic",
        "non-dual",
        "conscious",
        "sentient",
        "sacred",
        "infinite",
        "primordial",
        "ancient",
        "powerful",
        "spiritual",
        "higher",
        "advanced",
        "internal",
        "sublime",
        "technological",
        "dynamic",
        "life-affirming",
        "sensual",
        "unrestricted",
        "ever-present",
        "endless",
        "ethereal",
        "astral",
        "cosmic",
        "spatial",
        "transformative",
        "unified",
        "non-local",
        "mystical",
        "divine",
        "self-aware",
        "magical",
        "amazing",
        "interstellar",
        "unlimited",
        "authentic",
        "angelic",
        "karmic",
        "psychic",
        "pranic",
        "consciousness-expanding",
        "perennial",
        "heroic",
        "archetypal",
        "mythic",
        "intergalatic",
        "holistic",
        "joyous",
        "eternal",
    ],
    "adjBig": [
        "epic",
        "unimaginable",
        "colossal",
        "unfathomable",
        "magnificent",
        "enormous",
        "jaw-dropping",
        "ecstatic",
        "powerful",
        "untold",
        "astonishing",
        "incredible",
        "breathtaking",
        "staggering",
    ],
    "adjWith": [
        "aglow with",
        "buzzing with",
        "beaming with",
        "full of",
        "overflowing with",
        "radiating",
        "bursting with",
        "electrified with",
    ],
    "adjPrefix": ["ultra-", "supra-", "hyper-", "pseudo-"],
    "vtMass": [
        "inspire",
        "integrate",
        "ignite",
        "discover",
        "rediscover",
        "foster",
        "release",
        "manifest",
        "harmonize",
        "engender",
        "bring forth",
        "bring about",
        "create",
        "spark",
        "reveal",
        "generate",
        "leverage",
    ],
    "vtPerson": [
        "enlighten",
        "inspire",
        "empower",
        "unify",
        "strengthen",
        "recreate",
        "fulfill",
        "change",
        "develop",
        "heal",
        "awaken",
        "synergize",
        "ground",
        "bless",
        "beckon",
    ],
    "viPerson": [
        "exist",
        "believe",
        "grow",
        "live",
        "dream",
        "reflect",
        "heal",
        "vibrate",
        "self-actualize",
    ],
    "vtDestroy": [
        "destroy",
        "eliminate",
        "shatter",
        "disrupt",
        "sabotage",
        "exterminate",
        "obliterate",
        "eradicate",
        "extinguish",
        "erase",
        "confront",
    ],
    "nTheXOf": [
        "richness",
        "truth",
        "growth",
        "nature",
        "healing",
        "knowledge",
        "birth",
        "deeper meaning",
    ],
    "ppPerson": [
        "awakened",
        "re-energized",
        "recreated",
        "reborn",
        "guided",
        "aligned",
    ],
    "ppThingPrep": [
        "enveloped in",
        "transformed into",
        "nurtured by",
        "opened by",
        "immersed in",
        "engulfed in",
        "baptized in",
    ],
    "fixedAdvP": [
        "through non-local interactions",
        "inherent in nature",
        "at the quantum level",
        "at the speed of light",
        "of unfathomable proportions",
        "on a cosmic scale",
        "devoid of self",
        "of the creative act",
    ],
    "fixedAdvPPlace": [
        "in this dimension",
        "outside time",
        "within the Godhead",
        "at home in the cosmos",
    ],
    "fixedNP": [
        "expanding wave functions",
        "superpositions of possibilities",
        "electromagnetic forces",
        "electromagnetic resonance",
        "molecular structures",
        "atomic ionization",
        "electrical impulses",
        "a resonance cascade",
        "bio-electricity",
        "ultrasonic energy",
        "sonar energy",
        "vibrations",
        "frequencies",
        "four-dimensional superstructures",
        "ultra-sentient particles",
        "sub-atomic particles",
        "chaos-driven reactions",
        "supercharged electrons",
        "supercharged waveforms",
        "pulses",
        "transmissions",
        "morphogenetic fields",
        "bio-feedback",
        "meridians",
        "morphic resonance",
        "psionic wave oscillations",
    ],
    "nSubject": [
        "alternative medicine",
        "astrology",
        "tarot",
        "crystal healing",
        "the akashic record",
        "feng shui",
        "acupuncture",
        "homeopathy",
        "aromatherapy",
        "ayurvedic medicine",
        "faith healing",
        "prayer",
        "astral projection",
        "Kabala",
        "reiki",
        "naturopathy",
        "numerology",
        "affirmations",
        "the Law of Attraction",
        "tantra",
        "breathwork",
    ],
    "vOpenUp": [
        "give us access to",
        "enable us to access",
        "remove the barriers to",
        "clear a path toward",
        "let us access",
        "align us with",
        "amplify our connection to",
        "become our stepping-stone to",
        "be a gateway to",
    ],
    "vTraverse": [
        "traverse",
        "walk",
        "follow",
        "engage with",
        "go along",
        "roam",
        "navigate",
        "wander",
        "embark on",
    ],
    "nameOfGod": ["Gaia", "Shiva", "Parvati", "the Goddess", "Shakti"],
    "nBenefits": [
        "improved focus",
        "improved concentration",
        "extreme performance",
        "enlightenment",
        "cellular regeneration",
        "an enhanced sexual drive",
        "improved hydration",
        "psychic rejuvenation",
        "a healthier relationship with the Self",
    ],
    "adjProduct": [
        "alkaline",
        "quantum",
        "holographic",
        "zero-point energy",
        '"living"',
        "metaholistic",
        "ultraviolet",
        "ozonized",
        "ion-charged",
        "hexagonal-cell",
        "organic",
    ],
    "nProduct": [
        "water",
        "healing crystals",
        "Tibetan singing bowls",
        "malachite runes",
        "meditation bracelets",
        "healing wands",
        "rose quartz",
        "karma bracelets",
        "henna tattoos",
        "hemp garments",
        "hemp seeds",
        "tofu",
        "massage oil",
        "herbal incense",
        "cheesecloth tunics",
    ],
}