# ---------------------------------------------------------------------------- #
#                               Sentence patterns                              #
# ---------------------------------------------------------------------------- #

from typing import Dict, List


sentence_patterns: Dict[str, List[str]] = {
    "explain": [
        "${nMass} is the driver of ${nMass}.",
        "${nMass} is the ${nTheXOf} of ${nMass}, and of us.",
        "You and I are ${nPersonPlural} of the ${nCosmos}.",
        "We exist as ${fixedNP}.",
        "We ${viPerson}, we ${viPerson}, we are reborn.",
        "Nothing is impossible.",
        "This life is nothing short of a ${ing} ${nOf} of ${adj} ${nMass}.",
        'Consciousness consists of ${fixedNP} of quantum energy. "Quantum" means a ${ing} of the ${adj}.',
        "The goal of ${fixedNP} is to plant the seeds of ${nMass} rather than ${nMassBad}.",
        "${nMass} is a constant.",
        "By ${ing}, we ${viPerson}.",
        "The ${nCosmos} is ${adjWith} ${fixedNP}.",
        "To ${vTraverse} the ${nPath} is to become one with it.",
        "Today, science tells us that the essence of nature is ${nMass}.",
        "${nMass} requires exploration.",
    ],
    "warn": [
        "We can no longer afford to live with ${nMassBad}.",
        "Without ${nMass}, one cannot ${viPerson}.",
        "Only a ${nPerson} of the ${nCosmos} may ${vtMass} this ${nOf} of ${nMass}.",
        "You must take a stand against ${nMassBad}.",
        "Yes, it is possible to ${vtDestroy} the things that can ${vtDestroy} us, but not without ${nMass} on our side.",
        "${nMassBad} is the antithesis of ${nMass}.",
        "You may be ruled by ${nMassBad} without realizing it. Do not let it ${vtDestroy} the ${nTheXOf} of your ${nPath}.",
        "The complexity of the present time seems to demand a ${ing} of our ${nOurPlural} if we are going to survive.",
        "${nMassBad} is born in the gap where ${nMass} has been excluded.",
        "Where there is ${nMassBad}, ${nMass} cannot thrive.",
    ],
    "hope": [
        "Soon there will be a ${ing} of ${nMass} the likes of which the ${nCosmos} has never seen.",
        "It is time to take ${nMass} to the next level.",
        "Imagine a ${ing} of what could be.",
        "Eons from now, we ${nPersonPlural} will ${viPerson} like never before as we are ${ppPerson} by the ${nCosmos}.",
        "It is a sign of things to come.",
        "The future will be a ${adj} ${ing} of ${nMass}.",
        "This ${nPath} never ends.",
        "We must learn how to lead ${adj} lives in the face of ${nMassBad}.",
        "We must ${vtPerson} ourselves and ${vtPerson} others.",
        "The ${nOf} of ${nMass} is now happening worldwide.",
        "We are being called to explore the ${nCosmos} itself as an interface between ${nMass} and ${nMass}.",
        "It is in ${ing} that we are ${ppPerson}.",
        "The ${nCosmos} is approaching a tipping point.",
        "${nameOfGod} will ${vOpenUp} ${adj} ${nMass}.",
    ],
    "yourProblems": [
        "Although you may not realize it, you are ${adj}.",
        "${nPerson}, look within and ${vtPerson} yourself.",
        "Have you found your ${nPath}?",
        "How should you navigate this ${adj} ${nCosmos}?",
        "It can be difficult to know where to begin.",
        "If you have never experienced this ${nOf} ${fixedAdvP}, it can be difficult to ${viPerson}.",
        "The ${nCosmos} is calling to you via ${fixedNP}. Can you hear it?",
    ],
    "history": [
        "Throughout history, humans have been interacting with the ${nCosmos} via ${fixedNP}.",
        "Reality has always been ${adjWith} ${nPersonPlural} whose ${nOurPlural} are ${ppThingPrep} ${nMass}.",
        "Our conversations with other ${nPersonPlural} have led to a ${ing} of ${adjPrefix}${adj} consciousness.",
        "Humankind has nothing to lose.",
        "We are in the midst of a ${adj} ${ing} of ${nMass} that will ${vOpenUp} the ${nCosmos} itself.",
        "Who are we? Where on the great ${nPath} will we be ${ppPerson}?",
        "We are at a crossroads of ${nMass} and ${nMassBad}.",
    ],
    "selling": [
        "Through ${nSubject}, our ${nOurPlural} are ${ppThingPrep} ${nMass}.",
        "${nSubject} may be the solution to what's holding you back from a ${adjBig} ${nOf} of ${nMass}.",
        "You will soon be ${ppPerson} by a power deep within yourself - a power that is ${adj}, ${adj}.",
        "As you ${viPerson}, you will enter into infinite ${nMass} that transcends understanding.",
        "This is the vision behind our 100% ${adjProduct}, ${adjProduct} ${nProduct}.",
        "With our ${adjProduct} ${nProduct}, ${nBenefits} is only the beginning.",
    ],
}